// Copyright 2024 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto2";

package cel.expr.conformance.proto2;

import "cel/expr/conformance/proto2/test_all_types.proto";

option cc_enable_arenas = true;
option go_package = "cel.dev/expr/conformance/proto2";
option java_outer_classname = "TestAllTypesExtensions";
option java_package = "dev.cel.expr.conformance.proto2";
option java_multiple_files = true;

// Package scoped extensions
extend TestAllTypes {
  optional int32 int32_ext = 1000;
  optional TestAllTypes nested_ext = 1001;
  optional TestAllTypes test_all_types_ext = 1002;
  optional TestAllTypes.NestedEnum nested_enum_ext = 1003;
  repeated TestAllTypes repeated_test_all_types = 1004;
}

// Message scoped extensions
message Proto2ExtensionScopedMessage {
  extend TestAllTypes {
    optional int64 int64_ext = 1005;
    optional TestAllTypes message_scoped_nested_ext = 1006;
    optional TestAllTypes.NestedEnum nested_enum_ext = 1007;
    repeated TestAllTypes message_scoped_repeated_test_all_types = 1008;
  }
}
